about summary refs log tree commit homepage
path: root/lib/rainbows.rb
diff options
context:
space:
mode:
authorEric Wong <normalperson@yhbt.net>2010-10-20 17:48:58 -0700
committerEric Wong <normalperson@yhbt.net>2010-10-21 00:49:36 +0000
commitd4a2b5dd2b85f4b2d3bb120ee1e1b0dde31bc25c (patch)
tree85866cc775a213216701ccaedf16061f15d13975 /lib/rainbows.rb
parenta085ba3586756ac1f778d2862f75889de2449b0e (diff)
downloadrainbows-d4a2b5dd2b85f4b2d3bb120ee1e1b0dde31bc25c.tar.gz
We get basic internal API changes from Unicorn,
code simplifications coming next.
Diffstat (limited to 'lib/rainbows.rb')
-rw-r--r--lib/rainbows.rb5
1 files changed, 2 insertions, 3 deletions
diff --git a/lib/rainbows.rb b/lib/rainbows.rb
index 0914609..58ba23f 100644
--- a/lib/rainbows.rb
+++ b/lib/rainbows.rb
@@ -77,10 +77,9 @@ module Rainbows
 
     # returns a string representing the address of the given client +io+
     # For local UNIX domain sockets, this will return a string referred
# to by the (non-frozen) Unicorn::HttpRequest::LOCALHOST constant.
     def addr(io) # :nodoc:
-      io.respond_to?(:peeraddr) ?
-                        io.peeraddr[-1] : Unicorn::HttpRequest::LOCALHOST
+      io.respond_to?(:peeraddr) ? io.peeraddr[-1] : Kgio::LOCALHOST
     end
 
     # :stopdoc:
@@ -77,10 +77,9 @@ module Rainbows
     # returns a string representing the address of the given client +io+
     # For local UNIX domain sockets, this will return a string referred
-    # to by the (non-frozen) Unicorn::HttpRequest::LOCALHOST constant.
+    # to by the (non-frozen) Kgio::LOCALHOST constant.
     def addr(io) # :nodoc: